<?php

/**
 * @file
 */

namespace Drupal\Tests\content_snapshot\Functional;

use Drupal\Core\File\FileSystemInterface;
use Drupal\Tests\BrowserTestBase;
use Drush\TestTraits\DrushTestTrait;

/**
 * Class AbstractFunctional.
 */
abstract class AbstractFunctional extends BrowserTestBase {

  use DrushTestTrait;

  protected $defaultTheme = 'stark';

  /**
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /** @var \Drupal\Core\Entity\EntityTypeManagerInterface */
  protected $entityTypeManager;

  /**
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {

    parent::setUp();

    $this->entityTypeManager = $this->container->get('entity_type.manager');

    /** @var \Drupal\Core\Config\ConfigFactoryInterface $configFactory */
    $configFactory = $this->container->get('config.factory');
    $this->config = $configFactory->getEditable('content_snapshot.settings');

    $tempDirectory = $this->container->get('file_system')->getTempDirectory();
    $snapshotPath = "$tempDirectory/snapshot";

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $this->fileSystem = $fileSystem = $this->container->get('file_system');

    $fileSystem->prepareDirectory($snapshotPath, FileSystemInterface::CREATE_DIRECTORY);
    $fileSystem->saveData('', $fileSystem->createFilename('.snapshot', $snapshotPath));

    $this->config->set('snapshot_path', $snapshotPath);
    $this->config->save();

  }

}
